@@ -49,7 +49,7 @@ class NetworkDriver(object):
     def __enter__(self):
         try:
             self.open()
-        except:
+        except:  # noqa
             exc_info = sys.exc_info()
             self.__raise_clean_exception(exc_info[0], exc_info[1], exc_info[2])
         return self
@@ -59,6 +59,18 @@ class NetworkDriver(object):
         if exc_type is not None:
             self.__raise_clean_exception(exc_type, exc_value, exc_traceback)
 
+    def __del__(self):
+        """
+        This method is used to cleanup when the program is terminated suddenly.
+        We need to make sure the connection is closed properly and the configuration DB
+        is released (unlocked).
+        """
+        try:
+            if self.is_alive()["is_alive"]:
+                self.close()
+        except NotImplementedError:
+            pass
+
     @staticmethod
     def __raise_clean_exception(exc_type, exc_value, exc_traceback):
         """
@@ -471,7 +483,7 @@ class NetworkDriver(object):
         :param neighbor: Returns the configuration of a specific BGP neighbor.
 
         Main dictionary keys represent the group name and the values represent a dictionary having
-        the following keys:
+        the keys below. Neighbors which aren't members of a group will be stored in a key named "_":
             * type (string)
             * description (string)
             * apply_groups (string list)
@@ -1111,7 +1123,7 @@ class NetworkDriver(object):
         raise NotImplementedError
 
     def ping(self, destination, source=c.PING_SOURCE, ttl=c.PING_TTL, timeout=c.PING_TIMEOUT,
-             size=c.PING_SIZE, count=c.PING_COUNT):
+             size=c.PING_SIZE, count=c.PING_COUNT, vrf=c.PING_VRF):
         """
         Executes ping on the device and returns a dictionary with the result
 
@@ -1178,7 +1190,8 @@ class NetworkDriver(object):
                    destination,
                    source=c.TRACEROUTE_SOURCE,
                    ttl=c.TRACEROUTE_TTL,
-                   timeout=c.TRACEROUTE_TIMEOUT):
+                   timeout=c.TRACEROUTE_TIMEOUT,
+                   vrf=c.TRACEROUTE_VRF):
         """
         Executes traceroute on the device and returns a dictionary with the result.
 
