@@ -4,6 +4,8 @@
 from __future__ import print_function
 from __future__ import unicode_literals
 
+from napalm_base.utils import py23_compat
+
 
 def test_model(model, data):
     """Return if the dictionary `data` complies with the `model`."""
@@ -14,9 +16,12 @@ def test_model(model, data):
 
     correct_class = True
     for key, instance_class in model.items():
-        same_class = isinstance(data[key], instance_class)
-        correct_class = correct_class and same_class
-        if not same_class:
+        correct_class = isinstance(data[key], instance_class)
+        # Properly handle PY2 long
+        if py23_compat.PY2:
+            if isinstance(data[key], long) and isinstance(1, instance_class):  # noqa
+                correct_class = True
+        if not correct_class:
             print("key: {}\nmodel_class: {}\ndata_class: {}".format(
                                                     key, instance_class, data[key].__class__))
 
